/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
			8-Bit UART(send and receive for data) ATMEL ATmega8; auf dem STK500 board

Description: 	The code assume asynchronous operation using polling (no interrupts enabled) and a 
				fixed frame format. The baud rate is given as a function parameter.
				Init, send and receive data with the USART

Author: 		Peniely Lydos

AppNote:        AVR500 - USART implementation

Datum: 			26/05/2009

Version: 		0.0

File Name: 		ADC_USART_Init_usart.h

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


//----------------------------------------------------------------------------------------------------------------
//Internal Clock Generation - The Baud Rate Generator
//----------------------------------------------------------------------------------------------------------------
//Operating Mode			Equation for Calculating Baud Rate			Equation for Calculating UBRR Value
//
//Asynchronous Normal mode		BAUD = fOSC/(16(UBRR + 1))					UBRR = (fOSC/(16BAUD))-1
//		(U2X = 0)
//
//Asynchronous Double Speed		BAUD = fOSC/(8(UBRR + 1))					UBRR = (fOSC/(8BAUD))-1
//		Mode (U2X = 1)
//
//Synchronous Master Mode		BAUD = fOSC/(2(UBRR + 1))					UBRR = (fOSC/(2BAUD))-1
//
//----------------------------------------------------------------------------------------------------------------
//USART Control and Status Register A -UCSRA
//----------------------------------------------------------------------------------------------------------------
//RXC		TXC		UDRE		FE		DOR		UPE		U2X		MPCM
//1=>USART Receive Complete
//			1=>USART Transmit Complete
//					1=>USART Data Register Empty
//								1=>Frame Error
//										1=>Data OverRun
//												1=>parity checking was enabled at that point (UPM1 = 1)
//														1=>U2X: Double the USART transmission speed
//																1=>MPCM: Multi-processor Communication Mode
//----------------------------------------------------------------------------------------------------------------
//USART Control and Status Register B -UCSRB
//----------------------------------------------------------------------------------------------------------------
//RXCIE		TXCIE		UDRIE		RXEN		TXEN		UCSZ2		RXB8		TXB8
//1=>RX Complete Interrupt Enable
//			1=>TX Complete Interrupt Enable
//						1=>USART Data Register Empty Interrupt Enable
//									1=>Receiver Enable
//												1=>Transmitter Enable
//															1=>Character Size
//																		1=>Receive Data Bit 8
//																					1=>Transmit Data Bit 8
//----------------------------------------------------------------------------------------------------------------
//USART Control and Status Register C -UCSRC
//----------------------------------------------------------------------------------------------------------------
//URSEL		UMSEL (Mode Select)		UPM1	UPM0 (Parity Mode)			USBS: (Stop Bit Select)	UCSZ2 	UCSZ1 	UCSZ0 (Character Size)	UCPOL Bit Settings
//Register Select
//			0 Asynchronous Operation
//			1 Synchronous Operation
//									0		0 	Disabled
//									0 		1 	Reserved
//									1 		0 	Enabled, Even Parity
//									1 		1 	Enabled, Odd Parity
//																		0 			1-bit
//																		1 			2-bit
//																								  0 	  0 	  0 	5-bit
//																								  0 	  0 	  1 	6-bit
//																								  0       1 	  0 	7-bit
//																								  0 	  1 	  1 	8-bit
//																								  1 	  0 	  0 	Reserved
//																								  1 	  0 	  1 	Reserved
//																								  1 	  1 	  0 	Reserved
//																								  1 	  1 	  1 	9-bit
//																																		Output of TxD Pin 	Input on RxD Pin
//																																	0 	Rising XCK 			Edge Falling XCK Edge 
//																																	1 	Falling XCK Edge 	Rising XCK Edge


#include <inttypes.h>


//----------------------------------------------------------
// USART Functions definitions
//----------------------------------------------------------

void USART_Init(void);

void USART_Putc(unsigned char c);

void USART_Puts (char *string);

unsigned char USART_Receive();

void USART_Flush(); 

//-----------------------------------------------------------------------------
// Bit and byte definitions
//------------------------------------------------------------------------------
