/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		8-Bit-Analog-Digital-Converter mit ATMEL ATmega8 to STK500 board, output on (PortB) --> LEDs 

Description: 	The ADC converts an analog input voltage to a 10-bit digital value through successive 
				approximation. The minimum value represents GND and the maximum value represents the 
				voltage on the AREF. The converted value will be send on the anather PC throught USART interface

Author:			Peniely Lydos

AppNote:        AVR500 - ADC and USART implementation test

Datum: 			26/05/2009

Version: 		0.0

File Name: 		ADC_USART_Init_Main.c

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//----------------------------------------------------------------------------------------------------------------
//Timer/Counter Control Register TCCR0 
//----------------------------------------------------------------------------------------------------------------
//-	 -	-	-	-	CS02	CS01	CS00	Clock Select Bit Description
//					  0		  0		  0		No clock source (Timer/counter stopped)
//					  0		  0		  1		clki/o/(No prescaling)
//					  0		  1		  0		clki/o/8(From prescaling)
//					  0		  1		  1		clki/o/64(From prescaling)
//					  1		  0		  0		clki/o/256(From prescaling)
//					  1		  0		  1		clki/o/1024(From prescaling)
//					  1		  1		  0		External clock source on T0 pin. clock on falling edge
//					  1		  1		  1		External clock source on T0 pin. clock on rising edge
//----------------------------------------------------------------------------------------------------------------
//Timer/Counter Register TCNT0 [7:0]
//----------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------
//Timer/Counter Interrupt Mask Register TIMSK
//----------------------------------------------------------------------------------------------------------------
//OCIE2	TOIE2	TICIE1	OCIE1A	OCIE1B	TOIE1	-	TOIE0
//													1=>Timer/counter overflow interrupt is enable
//----------------------------------------------------------------------------------------------------------
//Timer/Counter Interrupt Flag Register TIFR
//----------------------------------------------------------------------------------------------------------------
//OCF2	TOV2	ICF1	OCF1A	OCF1B	TOV1	-	TOV0
//													1=>When an overflow occurs in Timer/counter0


#include <avr/io.h>
#include <inttypes.h>
#include <stdlib.h>
#include <avr/interrupt.h>
#include "ADC_USART_Init_usart.h"
#include "ADC_USART_Read_adc.h"




//defineglobal variables
int ADIteiler=0;
char s[20];


//Initialisation
void initall()
{
  USART_Init(); 
  
  //interrupt
  TCNT0 = 5;  			//Set Timer/counter
  TIMSK |= (1<<TOIE0);	//Enable Timer/counter0 overflow interrupt
  TCCR0 |= (1<<CS01);
  TCCR0 |= (1<<CS00);	//Select the clock source to be used by the timer/counter --> CPU Takt  --> 4MHz/64 
  TIFR |= (1<<TOV0);	//interrupt starts with each overflow   
}//End initall()


//Interrupt Service Routine fr AD Wandlung
ISR(TIMER0_OVF_vect) 
{
  ADIteiler++; 						//clocks interrupt counter value on each ms 
  if(ADIteiler >= 60)				//Counter cycle for all ms 60
  {
    ADIteiler=0;					//counter 0 set
        
	uint16_t result = ADC_Read(0);	//Reading the Analog voltage on PinC 0,
	USART_Puts("\r\n");
	utoa( result, s, 2 ); 			//convert HEX-Zahlen in Ascii
	USART_Puts( s );	
    USART_Putc('$');
	
	DDRB = 0xFF;					//define as output
  	PORTB = (result / 10) + 1;
	
  }
}//End ISR(TIMER0_OVF_vect) 


int main()
{
  initall();
  
  USART_Puts("\r\n");
  USART_Puts("Messung gestartet:");
  USART_Puts("\r\n");
  
  sei();												//Enable Globale Interrupts
  
  while (1) 
  {
  	unsigned char received = USART_Receive();       	// sends data
	if(received == 0x0D) 								// = ENTER-Taste
	{     
	  USART_Puts("\r\n");
	  //PORTB = received;
	}

	else 
	{
	  USART_Puts("\r\n");
	  USART_Putc(received );
	  if(   (received >= 0x61 && received <= 0x7A)	 	 //a     bis     z
	           || (received >= 0x41 && received <= 0x5A) //A     bis     Z 
	           || (received >= 0x30 && received <= 0x39) //0     bis    9 
	           || (received == 0x20)                   ) //<SPACE>
       
	 USART_Puts("\r\n");
	 USART_Putc(received);
	 USART_Puts("\r\n");
	 
	}//End else 
  }//End while   
}//End main()
